#!/usr/bin/python3

import moiety_modeling
import jsonpickle
import glob


def analyze(files, model, optimizationsetting, savePath):
    """
    Optimize model parameters for the corresponding datasets.
    :param files: the dataset files.
    :param model: the moiety model.
    :param optimizationsetting: the parameters for optimization setting.
    :param savePath: the path to save the results.
    :return:
    """

    for file in files:
        with open(file) as dataFile:
            dataset = jsonpickle.decode(dataFile.read())['datasets']
        manager = moiety_modeling.modeling.OptimizationManager(model, dataset, optimizationsetting, savePath, energyFunction='absDifference', printOptimizationScript=False)
        manager.optimizeModels()


if __name__ == "__main__":

    single_model_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/data/model_single.json'
    multi_model_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/data/model_multi.json'

    optimization_setting_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/data/SAGA_test.json'

    with open(single_model_path) as singleModelFile:
        singleModel = jsonpickle.decode(singleModelFile.read())['models']

    with open(multi_model_path) as multiModelFile:
        multiModel = jsonpickle.decode(multiModelFile.read())['models']

    with open(optimization_setting_path) as settingFile:
        optimizationSetting = jsonpickle.decode(settingFile.read())['optimizations']

    single_std_1_analysis = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.1_analysis'
    single_std_2_analysis = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.01_analysis'
    single_std_3_analysis = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.001_analysis'

    multi_std_1_analysis = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.1_analysis'
    multi_std_2_analysis = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.01_analysis'
    multi_std_3_analysis = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.001_analysis'

    single_std_1_data = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.1_dataset/*.json'
    single_std_2_data = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.01_dataset/*.json'
    single_std_3_data = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.001_dataset/*.json'

    multi_std_1_data = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.1_dataset/*.json'
    multi_std_2_data = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.01_dataset/*.json'
    multi_std_3_data = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.001_dataset/*.json'

    single_1_data_files = glob.glob(single_std_1_data)
    single_2_data_files = glob.glob(single_std_2_data)
    single_3_data_files = glob.glob(single_std_3_data)

    multi_1_data_files = glob.glob(multi_std_1_data)
    multi_2_data_files = glob.glob(multi_std_2_data)
    multi_3_data_files = glob.glob(multi_std_3_data)

    analyze(single_1_data_files, singleModel, optimizationSetting, single_std_1_analysis)
    analyze(single_2_data_files, singleModel, optimizationSetting, single_std_2_analysis)
    analyze(single_3_data_files, singleModel, optimizationSetting, single_std_3_analysis)

    analyze(multi_1_data_files, multiModel, optimizationSetting, multi_std_1_analysis)
    analyze(multi_2_data_files, multiModel, optimizationSetting, multi_std_2_analysis)
    analyze(multi_3_data_files, multiModel, optimizationSetting, multi_std_3_analysis)
