#!/usr/bin/python3

import jsonpickle
import matplotlib.pyplot as plt
import glob


def plotIsotopologueDistribution(files, isotopologue, defaultValue):

    collection = []
    for fileName in files:
        with open(fileName) as dataFile:
            data = jsonpickle.decode(dataFile.read())['datasets']
            for dataset in data:
                for molecule in dataset.keys():
                    isotopologues = dataset[molecule]
                    for item in isotopologues:
                        if item['labelingIsotopes'] == isotopologue:
                            collection.append(item['height'])
    plt.ylim(0, 70)
    plt.hist(collection, 100, range=[0, 0.5], align='mid')
    plt.axvline(x=defaultValue, color='red')
    plt.xlabel("Isotopologue intensity")
    plt.ylabel("Counts")
    plt.title(isotopologue, fontsize=10)
    plt.show()


if __name__ == "__main__":
    single_1_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.1_dataset/*.json'
    single_2_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.01_dataset/*.json'
    single_3_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.001_dataset/*.json'

    single_1_files = glob.glob(single_1_path)
    single_2_files = glob.glob(single_2_path)
    single_3_files = glob.glob(single_3_path)

    multi_1_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.1_dataset/*.json'
    multi_2_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.01_dataset/*.json'
    multi_3_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.001_dataset/*.json'

    multi_1_files = glob.glob(multi_1_path)
    multi_2_files = glob.glob(multi_2_path)
    multi_3_files = glob.glob(multi_3_path)

    plotIsotopologueDistribution(single_1_files, '13C_13', 0.335)
    plotIsotopologueDistribution(single_2_files, '13C_13', 0.335)
    plotIsotopologueDistribution(single_3_files, '13C_13', 0.335)

    plotIsotopologueDistribution(multi_1_files, '13C_13.18O_10', 0.199)
    plotIsotopologueDistribution(multi_2_files, '13C_13.18O_10', 0.199)
    plotIsotopologueDistribution(multi_3_files, '13C_13.18O_10', 0.199)