#!/usr/bin/python3

import jsonpickle
import matplotlib.pyplot as plt


def plotMoietyValue(file, defaultMoietyValue):
    """To plot the distribution of moiety states.

    :param file: the file contains the file names of the analysis results.
    :param defaultMoietyValue: the default values for the moiety states.
    :return: the dictionary of moiety states.
    """
    moietyValues = []
    with open(file) as pathFile:
        for fileName in pathFile:
            with open(fileName.replace("\n", "")) as dataFile:
                data = jsonpickle.decode(dataFile.read())
                currValues = data['moietyValues']
                for oneGuess in currValues:
                    for datasetName in oneGuess.keys():
                        moietyValues.append(oneGuess[datasetName])
    moietyCollections = {}
    for moietyState in moietyValues[0].keys():
        moietyValueList = [moietyValue[moietyState] for moietyValue in moietyValues]
        moietyCollections[moietyState] = moietyValueList
    nPlots = len(moietyCollections)
    labels = sorted(moietyCollections.keys())
    f = plt.figure(figsize=(2, 3))
    f.subplots_adjust(hspace=1, wspace=1)
    for i in range(nPlots):
        value = moietyCollections[labels[i]]
        defaultValue = defaultMoietyValue[labels[i]]
        f.add_subplot(int(nPlots / 5) + 1, 5, i + 1)
        plt.hist(value, 30, range=[0, 1], align='mid')
        plt.axvline(x=defaultValue, color='red')
        plt.xlabel("Moiety Value")
        plt.ylabel("Counts")
        plt.title("{0}".format(labels[i]), fontsize=10)
    plt.show()
    return moietyCollections


if __name__ == "__main__":
    single_1_analysis_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.1_analysis/SAGA_5000_absDifference_analysis/SAGA_5000_absDifference_analysis.txt'
    single_2_analysis_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.01_analysis/SAGA_5000_absDifference_analysis/SAGA_5000_absDifference_analysis.txt'
    single_3_analysis_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.001_analysis/SAGA_5000_absDifference_analysis/SAGA_5000_absDifference_analysis.txt'

    single_1_sta_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.1_analysis/'
    single_2_sta_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.01_analysis/'
    single_3_sta_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/single_std_0.001_analysis/'

    multi_1_analysis_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.1_analysis/SAGA_5000_absDifference_analysis/SAGA_5000_absDifference_analysis.txt'
    multi_2_analysis_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.01_analysis/SAGA_5000_absDifference_analysis/SAGA_5000_absDifference_analysis.txt'
    multi_3_analysis_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.001_analysis/SAGA_5000_absDifference_analysis/SAGA_5000_absDifference_analysis.txt'

    multi_1_sta_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.1_analysis/'
    multi_2_sta_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.01_analysis/'
    multi_3_sta_path = '/mlab/data/hji236/projects/moiety_modeling_analyses/results/multi_std_0.001_analysis/'

    singleDefaultValue = {'acetyl[13C_0]': 0.7, 'acetyl[13C_2]': 0.3, 'glucose[13C_0]': 0.1, 'glucose[13C_6]': 0.9,
                          'ribose[13C_0]': 0.1, 'ribose[13C_5]': 0.9, 'uracil[13C_0]': 0.2, 'uracil[13C_1]': 0.2,
                          'uracil[13C_2]': 0.5, 'uracil[13C_3]': 0.1}
    multiDefaultValue = {'acetyl[13C_0.18O_0]': 0.7, 'acetyl[13C_2.18O_1]': 0.3, 'glucose[13C_0.18O_0]': 0.1,
                         'glucose[13C_6.18O_5]': 0.9, 'ribose[13C_0.18O_0]': 0.1, 'ribose[13C_5.18O_4]': 0.9,
                         'uracil[13C_0.18O_0]': 0.2, 'uracil[13C_1.18O_0]': 0.2, 'uracil[13C_2.18O_0]': 0.25,
                         'uracil[13C_2.18O_1]': 0.25, 'uracil[13C_3.18O_0]': 0.05, 'uracil[13C_3.18O_1]': 0.05}

    single_1_moietyCollections = plotMoietyValue(single_1_analysis_path, singleDefaultValue)
    single_2_moietyCollections = plotMoietyValue(single_2_analysis_path, singleDefaultValue)
    single_3_moietyCollections = plotMoietyValue(single_3_analysis_path, singleDefaultValue)

    multi_1_moietyCollections = plotMoietyValue(multi_1_analysis_path, multiDefaultValue)
    multi_2_moietyCollections = plotMoietyValue(multi_2_analysis_path, multiDefaultValue)
    multi_3_moietyCollections = plotMoietyValue(multi_3_analysis_path, multiDefaultValue)
